import java.util.*;
import java.io.*;

public class Vertex implements Iterable<Integer>, Comparable<Vertex> {
    private int index;
    private int degree;
    private int colour;
    private int saturation;
    private boolean[] domain;              // domain[i] <-> colour i allowed
    private HashSet<Integer> adjacent; // set of indices of adjacent vertices
    private boolean flag; // to be used as required
    private int location;

    public Vertex (int index) {
	this.index = index;
	degree     = 0;
	colour     = -1;
	saturation = 0;
	adjacent   = new HashSet<Integer>();
	flag       = false;
	location = -1;
    }

    public Vertex (int index,int degree) {
	this.index  = index;
	this.degree = degree;
	colour      = -1;
	saturation  = 0;
	adjacent    = new HashSet<Integer>();
	flag        = false;
	location    = -1;
    }

    public Vertex clone(){
	Vertex v     = new Vertex(index);
	v.degree     = degree;
	v.colour     = colour;
	v.saturation = saturation;
	v.adjacent   = (HashSet<Integer>)adjacent.clone();
	v.flag       = false;
	v.location   = -1;
	return v;
    }

    public int getIndex(){return index;}
    public int getLocation(){return location;}
    public void setLocation(int i){location = i;}
    public int getDegree(){return degree;}
    public int getColour(){return colour;}
    public int getSaturation(){return saturation;}
    public void incrementSaturation(){saturation++;}
    public void decrementDegree(){degree--;}
    public void incrementDegree(){degree++;}    
    public boolean isAdjacent(Vertex v){return adjacent.contains(v.index);}
    public Iterator<Integer> iterator(){return adjacent.iterator();}
    public boolean getFlag(){return flag;}
    public void setFlag(boolean p){flag = p;}
    public boolean hasColour(int i){return domain[i];}
    public void removeColour(int i){domain[i] = false;}
    public void setDegree(int degree){this.degree = degree;}
    public void setColour(int colour){this.colour = colour;}
    
    public void init(int n){
	domain = new boolean[n]; 
	Arrays.fill(domain,true);
	colour = -1;
	saturation = 0;
	flag = false;
    }
    //
    // prior to colouring
    //

    public int colour(){
	for (colour=0;!domain[colour];colour++);
	domain[colour]=false;
	return colour;
    }
    //
    // colour vertex with lowest possible colour
    //
    
    public void makeAdjacent(Vertex v){
	if (!adjacent.contains(v.index)){
	    adjacent.add(v.index);
	    degree++;
	}
    }
	
    public void removeAdjacent(Vertex v){
	if (adjacent.contains(v.index)){
	    adjacent.remove(v.index);
	    degree--;
	}
    }
    //
    // vertex v is no longer adjacent to this
    //

    public String toString(){
	String s = "id: "+ index +" deg: "+ degree +" col: "+ colour +" satur: "+ saturation + " > ";
	for (int i : this) s = s + i +" ";
	return s;
    }

    public int compareTo(Vertex v){
	if (degree < v.getDegree()) return 1;
	if (degree == v.getDegree()) return 0;
	return -1;
    }
    //
    // to sort in descending degree order
    //

    public static void main(String[] args) throws IOException {
	Scanner sc   = new Scanner(new File(args[0]));
	String b = "";
	while (sc.hasNext() && !b.equals("p")) b = sc.next();
	sc.next();
	int n = sc.nextInt();          // # vertices
	int m = sc.nextInt();          // # edges
	Vertex[] v = new Vertex [n];
	int[][] A = new int[n][n];
	for (int i=0;i<n;i++){
	    for (int j=0;j<n;j++) A[i][j] = 0;
	    v[i] = new Vertex(i);
	}
	while (sc.hasNext()){
	    b     = sc.next(); // skip "edge"
	    int i = sc.nextInt() - 1;
	    int j = sc.nextInt() - 1;
	    A[i][j] = A[j][i] = 1;
	    v[i].makeAdjacent(v[j]);
	    v[j].makeAdjacent(v[i]);
	}
	sc.close();
	
	for (int i=0;i<n;i++) System.out.println(v[i]);

	Vertex[] v_new = new Vertex [n];
	for (int i=0;i<n;i++) v_new[i] = (Vertex)v[i].clone();
	for (int i=0;i<n;i++) System.out.println(v_new[i]);
	
    }
}
